@@ -14,7 +14,6 @@ test_that("console printing", {
 })
 
 test_that("check extention and print document", {
-  skip_if_not(has_zip())
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
   x <- ph_with_text(x, type = "body", str = "Hello world")
@@ -26,7 +25,6 @@ test_that("check extention and print document", {
 
 
 test_that("check template", {
-  skip_if_not(has_zip())
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
   x <- ph_with_text(x, type = "body", str = "Hello world")
@@ -43,7 +41,6 @@ test_that("check template", {
 
 
 test_that("slide remove", {
-  skip_if_not(has_zip())
   x <- read_pptx() %>%
     add_slide("Title and Content", "Office Theme") %>%
     ph_with_text(type = "body", str = "Hello world 1") %>%
@@ -60,13 +57,12 @@ test_that("slide remove", {
   expect_equal(length(x), 1)
 
   sm <- slide_summary(x)
-  expect_equal(sm$text, "Hello world 2")
+  expect_equal(sm[1,]$text, "Hello world 2")
 })
 
 
 
 test_that("ph remove", {
-  skip_if_not(has_zip())
   x <- read_pptx() %>%
     add_slide("Title and Content", "Office Theme") %>%
     ph_with_text(type = "body", str = "Hello world 1") %>%
@@ -83,7 +79,16 @@ test_that("ph remove", {
 })
 
 
+test_that("cursor is incremented as expected", {
+  x <- read_pptx()
+  for(i in 1:11){
+    x <- add_slide(x, "Title Slide", "Office Theme")
+    x <- ph_with_text(x, i, type = "ctrTitle")
+  }
+  expect_equal(nrow( slide_summary(x, 11) ), 1 )
+  expect_equal(x$slide$get_slide(11)$name(), "slide11.xml" )
 
+})
 
 unlink("*.pptx")
 unlink("*.emf")
